<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet version="1.0" 
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:office="urn:oasis:names:tc:opendocument:xmlns:office:1.0"
    xmlns:text="urn:oasis:names:tc:opendocument:xmlns:text:1.0"
    xmlns:xlink="http://www.w3.org/1999/xlink" 
    xmlns:table="urn:oasis:names:tc:opendocument:xmlns:table:1.0"
    xmlns:draw="urn:oasis:names:tc:opendocument:xmlns:drawing:1.0"
    xmlns:svg="urn:oasis:names:tc:opendocument:xmlns:svg-compatible:1.0"
    xmlns="http://www.utc.fr/ics/hdoc/xhtml"
    >
    <xsl:output method="xml" encoding="utf-8"/>
    <xsl:template match="/">
        <html>
            <head>
                <title>Mise en forme avec XSLT</title>
                <meta charset="utf-8"/>
            </head>
            <body>
                <xsl:apply-templates/>
            </body>
        </html>
    </xsl:template>
    
    <xsl:template match="office:body">
        <xsl:apply-templates/>
    </xsl:template>
    
    <xsl:template match="office:text">
        <xsl:apply-templates/>
    </xsl:template>
    
    <xsl:template match="section">
        <section>
            <xsl:apply-templates/>
        </section>
    </xsl:template>

    <!--gestion des titres de sections-->
    <xsl:template match="text:h">
        <header>
            <h1>
                <xsl:value-of select="."/>
            </h1>
        </header>
    </xsl:template>

	<!--gestion du contenu des sections-->
    <xsl:template match="div">
        <div>
            <xsl:apply-templates/>
        </div>
    </xsl:template>

	<!--gestion des paragraphes-->
    <xsl:template match="text:p">
        <p>
            <xsl:apply-templates/>
        </p>
    </xsl:template>
    
    <xsl:template match="draw:text-box[//text:p]">
        <xsl:value-of select="."/>
    </xsl:template>
    
    
    <!--gestion des listes-->
    <xsl:template match="text:list-item">
        <li>
            <xsl:apply-templates/>
        </li>
    </xsl:template>
    
	<!--gestion des éléments de listes-->
    <xsl:template match="text:list">
        <ul>
            <xsl:apply-templates/>
        </ul>
    </xsl:template>
    
    <!--gestion des paragraphes dans les listes-->
    <xsl:template match="text:p[name(parent::node())='text:list-item']">
     
            <p><xsl:apply-templates/></p>
      
    </xsl:template>
    
    <!--gestion des liens hypertextes-->
    <xsl:template match="text:a">
        <a>
            <xsl:attribute name="href">
                <xsl:value-of select="@xlink:href"/>
            </xsl:attribute>
            <xsl:value-of select="."/>
        </a>
    </xsl:template>
    
	<!--gestion des tableaux-->
    <xsl:template match="table:table">
        <table>
            <xsl:apply-templates/>
        </table>
    </xsl:template>

    <xsl:template match="table:table-row">
        <tr>
            <xsl:apply-templates/>
        </tr>
    </xsl:template>
    <xsl:template match="table:table-cell">
        <td>
            <xsl:apply-templates/>
        </td>
    </xsl:template>
    
   <!--gestion des images-->
    <xsl:template match="text:p[text:span/draw:frame/draw:image]">
        <img>
            <xsl:attribute name="src">
                <xsl:value-of select="text:span/draw:frame/draw:image/@xlink:href"/>
            </xsl:attribute>
            <xsl:attribute name="alt">
                <xsl:value-of select="text:span/draw:frame/@draw:name"/>
            </xsl:attribute>
        </img>
    </xsl:template>
   
    <xsl:template match="text:p[draw:frame/draw:image]">
        <img>
            <xsl:attribute name="src">
                <xsl:value-of select="draw:frame/draw:image/@xlink:href"/>
            </xsl:attribute>
            <xsl:attribute name="alt">
                <xsl:value-of select="draw:frame/@draw:name"/>
            </xsl:attribute>
        </img>
    </xsl:template>
   
   <!--gestion des portions italiques-->
    <xsl:template match="text:span[@text:style-name='T4']">
        <i>
            <xsl:value-of select="."/>
        </i>
    </xsl:template>
    
	<!--gestion des portions mise en valeurs-->
    <xsl:template match="text:span[@text:style-name='T3']">
        <em>
            <xsl:value-of select="."/>
        </em>
    </xsl:template>
    
    <xsl:template match="text:span[@text:style-name='T5']">
        <em>
            <xsl:value-of select="."/>
        </em>
    </xsl:template>

</xsl:stylesheet>
